Crate fc_pallet_black_hole

Crate fc_pallet_black_hole 

Black Hole Pallet

This pallet owns an account, which receives transfers from other accounts. Then, periodically it burns the balance the pallet account owns.

Re-exports

pub use weights::*;
pub use pallet::*;

Modules

pallet
The pallet module in each FRAME pallet hosts the most important items needed to construct this pallet.
weights